<?php

/**
 * @Module Name: 1Pay Payments | WHMCS
 * Plugin URI: http://1pay.in
 * Description: Extends WHMCS with 1Pay services
 * Version: 1.0.3
 * @author: Soumil Gada, Manisha Gupta
 * Author EMAIL: soumil.gada@mobilewaretech.com
 * @copyright: @2018 Mobilewaretech. All rights reserved
 */
// Require libraries needed for gateway module functions.
require_once __DIR__ . '/../../../init.php';
require_once __DIR__ . '/../../../includes/gatewayfunctions.php';
require_once __DIR__ . '/../../../includes/invoicefunctions.php';

// Detect module name from filename.
$onepay = basename(__FILE__, '.php');

// Fetch gateway configuration parameters.
$gatewayParams = getGatewayVariables($onepay);

// Die if module is not active.
if (!$gatewayParams['type']) {
    die("Module Not Activated");
}

// Retrieve data returned in payment gateway callback
// Varies per payment gateway

$response = $_POST;
$respData = $response['respData'];

$url = "https://pay.1paypg.in/payone/";
if ($gatewayParams['mode'] === "Sandbox") {
    $url = "http://139.59.1.254:8080/onepayVAS/";
}



$respDecrypt = $this->get_decrypt($respData);
$Result = json_decode($respDecrypt);


/**
 * Validate callback authenticity.
 */
$functions = new Functions();
$verificationResult = $functions->verify(array('url' => $url, 'respData' => $Result));

$parsedtxnid = $verificationResult->txn_id;
$parsedmerchantid = $verificationResult->merchant_id;
$parsedtxnamount = $verificationResult->txn_amount;
$parsedtxnstatus = $verificationResult->trans_status;
$responseMessage = $verificationResult->resp_message;


$invoiceId = $parsedtxnid;
$transactionId = $parsedtxnid;
$paymentAmount = $parsedtxnamount;
$paymentFee = "0";


if (($responseMessage === 'No Error.') && ($parsedtxnstatus !== 'NA')) {

    $transactionStatus = "Verified Transaction";
    if ($parsedtxnstatus == 'Ok') {
        $transactionStatus = "Transaction Successful";
        $success = true;
        
    } else if ($parsedtxnstatus == 'To') {
        $transactionStatus = "Sorry!!Your Transaction is Timed Out";
        $success = false;
    } else {
        $transactionStatus = "Transaction Failed";
        $success = false;
    }
} else {
    $vmessage = "Transaction Verification Failed";
    $success = false;
    $transactionStatus = "Transaction Failed";
}

// 


/**
 * Validate Callback Invoice ID.
 *
 * Checks invoice ID is a valid invoice number. Note it will count an
 * invoice in any status as valid.
 *
 * Performs a die upon encountering an invalid Invoice ID.
 *
 * Returns a normalised invoice ID.
 */
$invoiceId = checkCbInvoiceID($invoiceId, $gatewayParams['name']);

/**
 * Check Callback Transaction ID.
 *
 * Performs a check for any existing transactions with the same given
 * transaction number.
 *
 * Performs a die upon encountering a duplicate.
 */
checkCbTransID($transactionId);

/**
 * Log Transaction.
 *
 * Add an entry to the Gateway Log for debugging purposes.
 *
 * The debug data can be a string or an array. In the case of an
 * array it will be
 *
 * @param string $gatewayName        Display label
 * @param string|array $debugData    Data to log
 * @param string $transactionStatus  Status
 */
logTransaction($gatewayParams['name'], $_POST, $transactionStatus);

if ($success) {

    /**
     * Add Invoice Payment.
     *
     * Applies a payment transaction entry to the given invoice ID.
     *
     * @param int $invoiceId         Invoice ID
     * @param string $transactionId  Transaction ID
     * @param float $paymentAmount   Amount paid (defaults to full balance)
     * @param float $paymentFee      Payment fee (optional)
     * @param string $gatewayModule  Gateway module name
     */
    addInvoicePayment(
            $invoiceId, $transactionId, $paymentAmount, $paymentFee, $onepay
    );
}
